You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by st...@apache.org on 2011/10/11 21:52:46 UTC

svn commit: r1182053 [4/30] - in /subversion/branches/svn_mutex: ./ build/ build/ac-macros/ build/generator/ build/generator/swig/ build/generator/templates/ contrib/client-side/ contrib/hook-scripts/enforcer/ contrib/server-side/ notes/ notes/merge-tr...

Modified: subversion/branches/svn_mutex/subversion/bindings/javahl/native/org_apache_subversion_javahl_SVNClient.cpp
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/javahl/native/org_apache_subversion_javahl_SVNClient.cpp?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/javahl/native/org_apache_subversion_javahl_SVNClient.cpp (original)
+++ subversion/branches/svn_mutex/subversion/bindings/javahl/native/org_apache_subversion_javahl_SVNClient.cpp Tue Oct 11 19:52:34 2011
@@ -356,8 +356,9 @@ Java_org_apache_subversion_javahl_SVNCli
       JNIUtil::throwError(_("bad C++ this"));
       return;
     }
+  SVN::Pool tmpPool;
   StringArray targetsArr(jtargets);
-  Targets targets(targetsArr);
+  Targets targets(targetsArr, tmpPool);
   if (JNIUtil::isExceptionThrown())
     return;
 
@@ -434,8 +435,9 @@ Java_org_apache_subversion_javahl_SVNCli
   if (JNIUtil::isExceptionThrown())
     return NULL;
 
+  SVN::Pool tmpPool;
   StringArray targetsArr(jtargets);
-  Targets targets(targetsArr);
+  Targets targets(targetsArr, tmpPool);
   if (JNIUtil::isExceptionThrown())
     return NULL;
 
@@ -459,8 +461,9 @@ Java_org_apache_subversion_javahl_SVNCli
       JNIUtil::throwError(_("bad C++ this"));
       return;
     }
+  SVN::Pool tmpPool;
   StringArray targetsArr(jtargets);
-  Targets targets(targetsArr);
+  Targets targets(targetsArr, tmpPool);
   if (JNIUtil::isExceptionThrown())
     return;
 
@@ -538,8 +541,9 @@ Java_org_apache_subversion_javahl_SVNCli
       JNIUtil::throwError(_("bad C++ this"));
       return;
     }
+  SVN::Pool tmpPool;
   StringArray srcPathArr(jsrcPaths);
-  Targets srcPaths(srcPathArr);
+  Targets srcPaths(srcPathArr, tmpPool);
   if (JNIUtil::isExceptionThrown())
     return;
   JNIStringHolder destPath(jdestPath);
@@ -572,8 +576,9 @@ Java_org_apache_subversion_javahl_SVNCli
       JNIUtil::throwError(_("bad C++ this"));
       return;
     }
+  SVN::Pool tmpPool;
   StringArray targetsArr(jtargets);
-  Targets targets(targetsArr);
+  Targets targets(targetsArr, tmpPool);
   if (JNIUtil::isExceptionThrown())
     return;
 
@@ -917,8 +922,9 @@ Java_org_apache_subversion_javahl_SVNCli
 
 JNIEXPORT void JNICALL
 Java_org_apache_subversion_javahl_SVNClient_propertySetRemote
-(JNIEnv *env, jobject jthis, jstring jpath, jstring jname,
- jbyteArray jvalue, jboolean jforce, jobject jrevpropTable, jobject jcallback)
+(JNIEnv *env, jobject jthis, jstring jpath, jlong jbaseRev, jstring jname,
+ jbyteArray jval, jobject jmessage, jboolean jforce, jobject jrevpropTable,
+ jobject jcallback)
 {
   JNIEntry(SVNClient, propertySet);
   SVNClient *cl = SVNClient::getCppObject(jthis);
@@ -935,7 +941,11 @@ Java_org_apache_subversion_javahl_SVNCli
   if (JNIUtil::isExceptionThrown())
     return;
 
-  JNIByteArray value(jvalue);
+  CommitMessage message(jmessage);
+  if (JNIUtil::isExceptionThrown())
+    return;
+
+  JNIByteArray value(jval);
   if (JNIUtil::isExceptionThrown())
     return;
 
@@ -944,14 +954,15 @@ Java_org_apache_subversion_javahl_SVNCli
     return;
 
   CommitCallback callback(jcallback);
-  cl->propertySetRemote(path, name, value, jforce ? true:false, revprops,
-                        jcallback ? &callback : NULL);
+  cl->propertySetRemote(path, jbaseRev, name, &message, value,
+                        jforce ? true:false,
+                        revprops, jcallback ? &callback : NULL);
 }
 
 JNIEXPORT void JNICALL
 Java_org_apache_subversion_javahl_SVNClient_propertySetLocal
 (JNIEnv *env, jobject jthis, jobject jtargets, jstring jname,
- jbyteArray jvalue, jobject jdepth, jobject jchangelists, jboolean jforce)
+ jbyteArray jval, jobject jdepth, jobject jchangelists, jboolean jforce)
 {
   JNIEntry(SVNClient, propertySet);
   SVNClient *cl = SVNClient::getCppObject(jthis);
@@ -960,8 +971,9 @@ Java_org_apache_subversion_javahl_SVNCli
       JNIUtil::throwError(_("bad C++ this"));
       return;
     }
+  SVN::Pool tmpPool;
   StringArray targetsArr(jtargets);
-  Targets targets(targetsArr);
+  Targets targets(targetsArr, tmpPool);
   if (JNIUtil::isExceptionThrown())
     return;
 
@@ -969,7 +981,7 @@ Java_org_apache_subversion_javahl_SVNCli
   if (JNIUtil::isExceptionThrown())
     return;
 
-  JNIByteArray value(jvalue);
+  JNIByteArray value(jval);
   if (JNIUtil::isExceptionThrown())
     return;
 
@@ -1032,7 +1044,7 @@ Java_org_apache_subversion_javahl_SVNCli
 JNIEXPORT void JNICALL
 Java_org_apache_subversion_javahl_SVNClient_setRevProperty
 (JNIEnv *env, jobject jthis, jstring jpath, jstring jname, jobject jrevision,
- jstring jvalue, jstring joriginalValue, jboolean jforce)
+ jstring jval, jstring joriginalValue, jboolean jforce)
 {
   JNIEntry(SVNClient, setRevProperty);
   SVNClient *cl = SVNClient::getCppObject(jthis);
@@ -1053,7 +1065,7 @@ Java_org_apache_subversion_javahl_SVNCli
   if (JNIUtil::isExceptionThrown())
     return;
 
-  JNIStringHolder value(jvalue);
+  JNIStringHolder value(jval);
   if (JNIUtil::isExceptionThrown())
     return;
 
@@ -1159,10 +1171,10 @@ JNIEXPORT void JNICALL Java_org_apache_s
 }
 
 JNIEXPORT void JNICALL
-Java_org_apache_subversion_javahl_SVNClient_diff__Ljava_lang_String_2Lorg_apache_subversion_javahl_types_Revision_2Ljava_lang_String_2Lorg_apache_subversion_javahl_types_Revision_2Ljava_lang_String_2Ljava_lang_String_2Lorg_apache_subversion_javahl_types_Depth_2Ljava_util_Collection_2ZZZZ
+Java_org_apache_subversion_javahl_SVNClient_diff__Ljava_lang_String_2Lorg_apache_subversion_javahl_types_Revision_2Ljava_lang_String_2Lorg_apache_subversion_javahl_types_Revision_2Ljava_lang_String_2Ljava_io_OutputStream_2Lorg_apache_subversion_javahl_types_Depth_2Ljava_util_Collection_2ZZZZ
 (JNIEnv *env, jobject jthis, jstring jtarget1, jobject jrevision1,
  jstring jtarget2, jobject jrevision2, jstring jrelativeToDir,
- jstring joutfileName, jobject jdepth, jobject jchangelists,
+ jobject jstream, jobject jdepth, jobject jchangelists,
  jboolean jignoreAncestry, jboolean jnoDiffDeleted, jboolean jforce,
  jboolean jcopiesAsAdds)
 {
@@ -1193,7 +1205,7 @@ Java_org_apache_subversion_javahl_SVNCli
   if (JNIUtil::isExceptionThrown())
     return;
 
-  JNIStringHolder outfileName(joutfileName);
+  OutputStream dataOut(jstream);
   if (JNIUtil::isExceptionThrown())
     return;
 
@@ -1201,7 +1213,7 @@ Java_org_apache_subversion_javahl_SVNCli
   if (JNIUtil::isExceptionThrown())
     return;
 
-  cl->diff(target1, revision1, target2, revision2, relativeToDir, outfileName,
+  cl->diff(target1, revision1, target2, revision2, relativeToDir, dataOut,
            EnumMapper::toDepth(jdepth), changelists,
            jignoreAncestry ? true:false,
            jnoDiffDeleted ? true:false, jforce ? true:false,
@@ -1209,10 +1221,10 @@ Java_org_apache_subversion_javahl_SVNCli
 }
 
 JNIEXPORT void JNICALL
-Java_org_apache_subversion_javahl_SVNClient_diff__Ljava_lang_String_2Lorg_apache_subversion_javahl_types_Revision_2Lorg_apache_subversion_javahl_types_Revision_2Lorg_apache_subversion_javahl_types_Revision_2Ljava_lang_String_2Ljava_lang_String_2Lorg_apache_subversion_javahl_types_Depth_2Ljava_util_Collection_2ZZZZ
+Java_org_apache_subversion_javahl_SVNClient_diff__Ljava_lang_String_2Lorg_apache_subversion_javahl_types_Revision_2Lorg_apache_subversion_javahl_types_Revision_2Lorg_apache_subversion_javahl_types_Revision_2Ljava_lang_String_2Ljava_io_OutputStream_2Lorg_apache_subversion_javahl_types_Depth_2Ljava_util_Collection_2ZZZZ
 (JNIEnv *env, jobject jthis, jstring jtarget, jobject jpegRevision,
  jobject jstartRevision, jobject jendRevision, jstring jrelativeToDir,
- jstring joutfileName, jobject jdepth, jobject jchangelists,
+ jobject jstream, jobject jdepth, jobject jchangelists,
  jboolean jignoreAncestry, jboolean jnoDiffDeleted, jboolean jforce,
  jboolean jcopiesAsAdds)
 {
@@ -1239,7 +1251,7 @@ Java_org_apache_subversion_javahl_SVNCli
   if (JNIUtil::isExceptionThrown())
     return;
 
-  JNIStringHolder outfileName(joutfileName);
+  OutputStream dataOut(jstream);
   if (JNIUtil::isExceptionThrown())
     return;
 
@@ -1252,7 +1264,7 @@ Java_org_apache_subversion_javahl_SVNCli
     return;
 
   cl->diff(target, pegRevision, startRevision, endRevision, relativeToDir,
-           outfileName, EnumMapper::toDepth(jdepth), changelists,
+           dataOut, EnumMapper::toDepth(jdepth), changelists,
            jignoreAncestry ? true:false,
            jnoDiffDeleted ? true:false, jforce ? true:false,
            jcopiesAsAdds ? true:false);
@@ -1575,8 +1587,9 @@ Java_org_apache_subversion_javahl_SVNCli
       JNIUtil::throwError("bad C++ this");
       return;
     }
+  SVN::Pool tmpPool;
   StringArray targetsArr(jtargets);
-  Targets targets(targetsArr);
+  Targets targets(targetsArr, tmpPool);
   if (JNIUtil::isExceptionThrown())
     return;
 
@@ -1604,8 +1617,9 @@ Java_org_apache_subversion_javahl_SVNCli
       JNIUtil::throwError("bad C++ this");
       return;
     }
+  SVN::Pool tmpPool;
   StringArray targetsArr(jtargets);
-  Targets targets(targetsArr);
+  Targets targets(targetsArr, tmpPool);
   if (JNIUtil::isExceptionThrown())
     return;
 
@@ -1654,8 +1668,9 @@ Java_org_apache_subversion_javahl_SVNCli
       JNIUtil::throwError("bad C++ this");
       return;
     }
+  SVN::Pool tmpPool;
   StringArray targetsArr(jtargets);
-  Targets targets(targetsArr);
+  Targets targets(targetsArr, tmpPool);
   if (JNIUtil::isExceptionThrown())
     return;
 
@@ -1678,8 +1693,9 @@ Java_org_apache_subversion_javahl_SVNCli
       return;
     }
 
+  SVN::Pool tmpPool;
   StringArray targetsArr(jtargets);
-  Targets targets(targetsArr);
+  Targets targets(targetsArr, tmpPool);
   if (JNIUtil::isExceptionThrown())
     return;
 

Modified: subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/ClientNotifyInformation.java
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/ClientNotifyInformation.java?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/ClientNotifyInformation.java (original)
+++ subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/ClientNotifyInformation.java Tue Oct 11 19:52:34 2011
@@ -468,6 +468,9 @@ public class ClientNotifyInformation ext
         /** Skipping a working only node */
         update_skip_working_only ("update skip working only"),
 
+        /** Skipped a file or directory to which access couldn't be obtained */
+        update_skip_access_denied ("update skip access denied"),
+
         /** An update operation removed an external working copy.  */
         update_external_removed ("update external removed"),
 

Modified: subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/CommitInfo.java
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/CommitInfo.java?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/CommitInfo.java (original)
+++ subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/CommitInfo.java Tue Oct 11 19:52:34 2011
@@ -28,7 +28,7 @@ import java.util.Date;
 import org.apache.subversion.javahl.types.LogDate;
 
 /**
- * This class describes a item which will be commited.
+ * This class describes a item which will be committed.
  */
 public class CommitInfo implements java.io.Serializable
 {
@@ -41,7 +41,7 @@ public class CommitInfo implements java.
     // http://java.sun.com/javase/6/docs/platform/serialization/spec/version.html#6678
     private static final long serialVersionUID = 1L;
 
-    /** the revision commited */
+    /** the revision committed */
     long revision;
 
     /** the date of the revision */
@@ -50,13 +50,21 @@ public class CommitInfo implements java.
     /** the author of the revision */
     String author;
 
+    /** post commit error (or NULL) */
+    String postCommitError;
+
+    /** repos root (or NULL) */
+    String reposRoot;
+
     /** This constructor will be only called from the jni code.  */
-    public CommitInfo(long rev, String d, String a)
+    public CommitInfo(long rev, String d, String a, String pce, String rr)
             throws java.text.ParseException
     {
         revision = rev;
         date = (new LogDate(d)).getDate();
         author = a;
+        postCommitError = pce;
+        reposRoot = rr;
     }
 
     /**
@@ -82,4 +90,20 @@ public class CommitInfo implements java.
     {
         return author;
     }
+
+    /**
+     * return any post commit error for the commit
+     */
+    public String getPostCommitError()
+    {
+        return postCommitError;
+    }
+
+    /**
+     * return the repos root
+     */
+    public String getReposRoot()
+    {
+        return reposRoot;
+    }
 }

Modified: subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/CommitItem.java
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/CommitItem.java?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/CommitItem.java (original)
+++ subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/CommitItem.java Tue Oct 11 19:52:34 2011
@@ -26,7 +26,7 @@ package org.apache.subversion.javahl;
 import org.apache.subversion.javahl.types.NodeKind;
 
 /**
- * This class describes a item which will be commited.
+ * This class describes a item which will be committed.
  */
 public class CommitItem implements java.io.Serializable
 {
@@ -50,7 +50,7 @@ public class CommitItem implements java.
     NodeKind nodeKind;
 
     /**
-     * the kind of change to be commited (See CommitItemStateFlages)
+     * the kind of change to be committed (See CommitItemStateFlages)
      */
     int stateFlags;
 

Modified: subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/CommitItemStateFlags.java
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/CommitItemStateFlags.java?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/CommitItemStateFlags.java (original)
+++ subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/CommitItemStateFlags.java Tue Oct 11 19:52:34 2011
@@ -25,7 +25,7 @@ package org.apache.subversion.javahl;
 
 /**
  * The constants in this interface describe the changes to an item to
- * be commited.
+ * be committed.
  */
 public interface CommitItemStateFlags
 {

Modified: subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/ISVNClient.java
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/ISVNClient.java?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/ISVNClient.java (original)
+++ subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/ISVNClient.java Tue Oct 11 19:52:34 2011
@@ -84,7 +84,7 @@ public interface ISVNClient
             throws ClientException;
 
     /**
-     * Lists the directory entries of an url on the server.
+     * Lists the directory entries of a url on the server.
      * @param url             the url to list
      * @param revision        the revision to list
      * @param pegRevision     the revision to interpret url
@@ -524,6 +524,13 @@ public interface ISVNClient
      * @throws ClientException
      */
     void diff(String target1, Revision revision1, String target2,
+              Revision revision2, String relativeToDir, OutputStream outStream,
+              Depth depth, Collection<String> changelists,
+              boolean ignoreAncestry, boolean noDiffDeleted, boolean force,
+              boolean copiesAsAdds)
+            throws ClientException;
+
+    void diff(String target1, Revision revision1, String target2,
               Revision revision2, String relativeToDir, String outFileName,
               Depth depth, Collection<String> changelists,
               boolean ignoreAncestry, boolean noDiffDeleted, boolean force,
@@ -548,6 +555,14 @@ public interface ISVNClient
      * @throws ClientException
      */
     void diff(String target, Revision pegRevision, Revision startRevision,
+              Revision endRevision, String relativeToDir,
+              OutputStream outStream,
+              Depth depth, Collection<String> changelists,
+              boolean ignoreAncestry, boolean noDiffDeleted, boolean force,
+              boolean copiesAsAdds)
+            throws ClientException;
+
+    void diff(String target, Revision pegRevision, Revision startRevision,
               Revision endRevision, String relativeToDir, String outFileName,
               Depth depth, Collection<String> changelists,
               boolean ignoreAncestry, boolean noDiffDeleted, boolean force,
@@ -649,7 +664,8 @@ public interface ISVNClient
                           boolean force)
             throws ClientException;
 
-    void propertySetRemote(String path, String name, byte[] value,
+    void propertySetRemote(String path, long baseRev, String name,
+                           byte[] value, CommitMessageCallback handler,
                            boolean force, Map<String, String> revpropTable,
                            CommitCallback callback)
             throws ClientException;

Modified: subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/NativeResources.java
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/NativeResources.java?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/NativeResources.java (original)
+++ subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/NativeResources.java Tue Oct 11 19:52:34 2011
@@ -131,10 +131,10 @@ public class NativeResources
     {
         initNativeLibrary();
         version = new Version();
-        if (!version.isAtLeast(1, 5, 0))
+        if (!version.isAtLeast(1, 7, 0))
         {
             throw new LinkageError("Native library version must be at least " +
-                                   "1.5.0, but is only " + version);
+                                   "1.7.0, but is only " + version);
         }
     }
 

Modified: subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/SVNClient.java
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/SVNClient.java?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/SVNClient.java (original)
+++ subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/SVNClient.java Tue Oct 11 19:52:34 2011
@@ -27,6 +27,8 @@ import org.apache.subversion.javahl.call
 import org.apache.subversion.javahl.types.*;
 
 import java.io.OutputStream;
+import java.io.FileOutputStream;
+import java.io.FileNotFoundException;
 import java.io.ByteArrayOutputStream;
 
 import java.util.Collection;
@@ -264,17 +266,53 @@ public class SVNClient implements ISVNCl
                                        LogMessageCallback callback)
         throws ClientException;
 
+    public void diff(String target1, Revision revision1, String target2,
+                     Revision revision2, String relativeToDir,
+                     String outFileName, Depth depth,
+                     Collection<String> changelists,
+                     boolean ignoreAncestry, boolean noDiffDeleted,
+                     boolean force, boolean copiesAsAdds)
+            throws ClientException
+    {
+        try {
+            OutputStream stream = new FileOutputStream(outFileName);
+            diff(target1, revision1, target2, revision2, relativeToDir,
+                 stream, depth, changelists, ignoreAncestry, noDiffDeleted,
+                 force, copiesAsAdds);
+        } catch (FileNotFoundException ex) {
+            throw ClientException.fromException(ex);
+        }
+    }
+
     public native void diff(String target1, Revision revision1, String target2,
                             Revision revision2, String relativeToDir,
-                            String outFileName, Depth depth,
+                            OutputStream stream, Depth depth,
                             Collection<String> changelists,
                             boolean ignoreAncestry, boolean noDiffDeleted,
                             boolean force, boolean copiesAsAdds)
             throws ClientException;
 
+    public void diff(String target, Revision pegRevision,
+                     Revision startRevision, Revision endRevision,
+                     String relativeToDir, String outFileName,
+                     Depth depth, Collection<String> changelists,
+                     boolean ignoreAncestry, boolean noDiffDeleted,
+                     boolean force, boolean copiesAsAdds)
+            throws ClientException
+    {
+        try {
+            OutputStream stream = new FileOutputStream(outFileName);
+            diff(target, pegRevision, startRevision, endRevision,
+                 relativeToDir, stream, depth, changelists, ignoreAncestry,
+                 noDiffDeleted, force, copiesAsAdds);
+        } catch (FileNotFoundException ex) {
+            throw ClientException.fromException(ex);
+        }
+    }
+
     public native void diff(String target, Revision pegRevision,
                             Revision startRevision, Revision endRevision,
-                            String relativeToDir, String outFileName,
+                            String relativeToDir, OutputStream stream,
                             Depth depth, Collection<String> changelists,
                             boolean ignoreAncestry, boolean noDiffDeleted,
                             boolean force, boolean copiesAsAdds)
@@ -307,7 +345,9 @@ public class SVNClient implements ISVNCl
                                         boolean force)
             throws ClientException;
 
-    public native void propertySetRemote(String path, String name, byte[] value,
+    public native void propertySetRemote(String path, long baseRev,
+                                         String name, byte[] value,
+                                         CommitMessageCallback handler,
                                          boolean force,
                                          Map<String, String> revpropTable,
                                          CommitCallback callback)

Propchange: subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/callback/BlameCallback.java
------------------------------------------------------------------------------
    svn:eol-style = native

Modified: subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/callback/CommitMessageCallback.java
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/callback/CommitMessageCallback.java?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/types/ChangePath.java (original)
+++ subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/types/ChangePath.java Tue Oct 11 19:52:34 2011
@@ -55,7 +55,7 @@ public class ChangePath implements java.
         this.propMods = propMods;
     }
 
-    /** Path of commited item */
+    /** Path of committed item */
     private String path;
 
     /** Source revision of copy (if any). */
@@ -77,8 +77,8 @@ public class ChangePath implements java.
     private Tristate propMods;
 
     /**
-     * Retrieve the path to the commited item
-     * @return  the path to the commited item
+     * Retrieve the path to the committed item
+     * @return  the path to the committed item
      */
     public String getPath()
     {

Modified: subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/types/Revision.java
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/types/Revision.java?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/types/Revision.java (original)
+++ subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/types/Revision.java Tue Oct 11 19:52:34 2011
@@ -145,7 +145,7 @@ public class Revision implements java.io
     }
 
     /**
-     * last commited revision
+     * last committed revision
      */
     public static final Revision HEAD = new Revision(Kind.head);
 

Propchange: subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/types/Tristate.java
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/BlameCallback3.java
------------------------------------------------------------------------------
    svn:eol-style = native

Modified: subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/ChangePath.java
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/ChangePath.java?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/ChangePath.java (original)
+++ subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/ChangePath.java Tue Oct 11 19:52:34 2011
@@ -72,7 +72,7 @@ public class ChangePath implements java.
         return path.compareTo(((ChangePath)other).path);
     }
 
-    /** Path of commited item */
+    /** Path of committed item */
     private String path;
 
     /** Source revision of copy (if any). */
@@ -88,8 +88,8 @@ public class ChangePath implements java.
     private int nodeKind;
 
     /**
-     * Retrieve the path to the commited item
-     * @return  the path to the commited item
+     * Retrieve the path to the committed item
+     * @return  the path to the committed item
      */
     public String getPath()
     {

Modified: subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/CommitItem.java
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/CommitItem.java?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/CommitItem.java (original)
+++ subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/CommitItem.java Tue Oct 11 19:52:34 2011
@@ -24,7 +24,7 @@
 package org.tigris.subversion.javahl;
 
 /**
- * This class describes a item which will be commited.
+ * This class describes a item which will be committed.
  */
 public class CommitItem implements java.io.Serializable
 {
@@ -48,7 +48,7 @@ public class CommitItem implements java.
     int nodeKind;
 
     /**
-     * the kind of change to be commited (See CommitItemStateFlages)
+     * the kind of change to be committed (See CommitItemStateFlages)
      */
     int stateFlags;
 

Modified: subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/CommitItemStateFlags.java
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/CommitItemStateFlags.java?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/CommitItemStateFlags.java (original)
+++ subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/CommitItemStateFlags.java Tue Oct 11 19:52:34 2011
@@ -25,7 +25,7 @@ package org.tigris.subversion.javahl;
 
 /**
  * The constants in this interface describe the changes to an item to
- * be commited.
+ * be committed.
  */
 public interface CommitItemStateFlags
 {

Modified: subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/CommitMessage.java
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/CommitMessage.java?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/Revision.java (original)
+++ subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/Revision.java Tue Oct 11 19:52:34 2011
@@ -177,7 +177,7 @@ public class Revision implements java.io
     }
 
     /**
-     * last commited revision
+     * last committed revision
      */
     public static final Revision HEAD = new Revision(Kind.head, true);
 

Modified: subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/SVNAdmin.java
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/SVNAdmin.java?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/SVNAdmin.java (original)
+++ subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/SVNAdmin.java Tue Oct 11 19:52:34 2011
@@ -59,7 +59,6 @@ public class SVNAdmin
      */
     protected void finalize()
     {
-        aSVNAdmin.finalize();
     }
 
     /**

Modified: subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/SVNClient.java
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/SVNClient.java?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/SVNClient.java (original)
+++ subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/SVNClient.java Tue Oct 11 19:52:34 2011
@@ -70,7 +70,6 @@ public class SVNClient implements SVNCli
      */
     protected void finalize()
     {
-        aSVNClient.finalize();
     }
 
     /**
@@ -1878,8 +1877,12 @@ public class SVNClient implements SVNCli
         {
             if (Path.isURL(path))
             {
-                aSVNClient.propertySetRemote(path, name,
+                Info2[] infos = info2(path, Revision.HEAD, Revision.HEAD,
+                                      false);
+
+                aSVNClient.propertySetRemote(path, infos[0].getRev(), name,
                                        value == null ? null : value.getBytes(),
+                                       cachedHandler,
                                        force, revpropTable, null);
             }
             else

Modified: subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/SVNClientInterface.java
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/SVNClientInterface.java?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/SVNClientInterface.java (original)
+++ subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/SVNClientInterface.java Tue Oct 11 19:52:34 2011
@@ -154,7 +154,7 @@ public interface SVNClientInterface
             throws ClientException;
 
     /**
-     * Lists the directory entries of an url on the server.
+     * Lists the directory entries of a url on the server.
      * @param url       the url to list
      * @param revision  the revision to list
      * @param recurse   recurse into subdirectories
@@ -167,7 +167,7 @@ public interface SVNClientInterface
             throws ClientException;
 
     /**
-     * Lists the directory entries of an url on the server.
+     * Lists the directory entries of a url on the server.
      * @param url       the url to list
      * @param revision  the revision to list
      * @param pegRevision the revision to interpret url
@@ -182,7 +182,7 @@ public interface SVNClientInterface
             throws ClientException;
 
     /**
-     * Lists the directory entries of an url on the server.
+     * Lists the directory entries of a url on the server.
      * @param url             the url to list
      * @param revision        the revision to list
      * @param pegRevision     the revision to interpret url
@@ -436,7 +436,7 @@ public interface SVNClientInterface
 
     /**
      * Sets the commit message handler. This allows more complex commit message
-     * with the list of the elements to be commited as input.
+     * with the list of the elements to be committed as input.
      * @param messageHandler    callback for entering commit messages
      *                          if this is set the message parameter is ignored.
      * @since 1.0
@@ -707,7 +707,7 @@ public interface SVNClientInterface
      *
      * @param srcPath   source path or url
      * @param destPath  destination path or url
-     * @param message   commit message if destPath is an url
+     * @param message   commit message if destPath is a url
      * @param revision  source revision
      * @throws ClientException
      * @deprecated Use {@link #copy(CopySource[], String, String, boolean,
@@ -754,7 +754,7 @@ public interface SVNClientInterface
      *
      * @param srcPath   source path or url
      * @param destPath  destination path or url
-     * @param message   commit message if destPath is an url
+     * @param message   commit message if destPath is a url
      * @param force     even with local modifications.
      * @throws ClientException
      * @deprecated Use {@link #move(String[], String, String, boolean, boolean,

Modified: subversion/branches/svn_mutex/subversion/bindings/javahl/tests/org/apache/subversion/javahl/BasicTests.java
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/javahl/tests/org/apache/subversion/javahl/BasicTests.java?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/javahl/tests/org/apache/subversion/javahl/BasicTests.java (original)
+++ subversion/branches/svn_mutex/subversion/bindings/javahl/tests/org/apache/subversion/javahl/BasicTests.java Tue Oct 11 19:52:34 2011
@@ -32,6 +32,7 @@ import java.io.FileReader;
 import java.io.IOException;
 import java.io.PrintWriter;
 import java.io.ByteArrayOutputStream;
+import java.io.UnsupportedEncodingException;
 import java.text.ParseException;
 import java.util.Collection;
 import java.util.Arrays;
@@ -130,6 +131,35 @@ public class BasicTests extends SVNTests
     }
 
     /**
+     * Test the JNIError class functionality
+     * @throws Throwable
+     */
+    public void testJNIError() throws Throwable
+    {
+        // build the test setup.
+        OneTest thisTest = new OneTest();
+
+        // Create a client, dispose it, then try to use it later
+        ISVNClient tempclient = new SVNClient();
+        tempclient.dispose();
+
+        // create Y and Y/Z directories in the repository
+        addExpectedCommitItem(null, thisTest.getUrl().toString(), "Y", NodeKind.none,
+                              CommitItemStateFlags.Add);
+        Set<String> urls = new HashSet<String>(1);
+        urls.add(thisTest.getUrl() + "/Y");
+        try 
+        {
+            tempclient.mkdir(urls, false, null, new ConstMsg("log_msg"), null);
+        } 
+        catch(JNIError e)
+        {
+	        return; // Test passes!
+        }
+        fail("A JNIError should have been thrown here.");
+    }
+
+    /**
      * Tests Mergeinfo and RevisionRange classes.
      * @since 1.5
      */
@@ -3081,6 +3111,53 @@ public class BasicTests extends SVNTests
     }
 
     /**
+     * Test the basic SVNClient.propertySetRemote functionality.
+     * @throws Throwable
+     */
+    public void testPropEdit() throws Throwable
+    {
+        final String PROP = "abc";
+        final byte[] VALUE = new String("def").getBytes();
+        final byte[] NEWVALUE = new String("newvalue").getBytes();
+        // create the test working copy
+        OneTest thisTest = new OneTest();
+
+        Set<String> pathSet = new HashSet<String>();
+        // set a property on A/D/G/rho file
+        pathSet.clear();
+        pathSet.add(thisTest.getWCPath()+"/A/D/G/rho");
+        client.propertySetLocal(pathSet, PROP, VALUE,
+                                Depth.infinity, null, false);
+        thisTest.getWc().setItemPropStatus("A/D/G/rho", Status.Kind.modified);
+
+        // test the status of the working copy
+        thisTest.checkStatus();
+
+        // commit the changes
+        checkCommitRevision(thisTest, "wrong revision number from commit", 2,
+                            thisTest.getWCPathSet(), "log msg", Depth.infinity,
+                            false, false, null, null);
+
+        thisTest.getWc().setItemPropStatus("A/D/G/rho", Status.Kind.normal);
+
+        // check the status of the working copy
+        thisTest.checkStatus();
+        
+        // now edit the propval directly in the repository
+        long baseRev = 2L;
+        client.propertySetRemote(thisTest.getUrl()+"/A/D/G/rho", baseRev, PROP, NEWVALUE,
+                                 new ConstMsg("edit prop"), false, null, null);
+        
+        // update the WC and verify that the property was changed
+        client.update(thisTest.getWCPathSet(), Revision.HEAD, Depth.infinity, false, false,
+                      false, false);
+        byte[] propVal = client.propertyGet(thisTest.getWCPath()+"/A/D/G/rho", PROP, null, null);
+
+        assertEquals(new String(propVal), new String(NEWVALUE));
+
+    }
+
+    /**
      * Test tolerance of unversioned obstructions when adding paths with
      * {@link org.apache.subversion.javahl.SVNClient#checkout()},
      * {@link org.apache.subversion.javahl.SVNClient#update()}, and
@@ -3343,6 +3420,16 @@ public class BasicTests extends SVNTests
     }
 
     /**
+     * Test an explicit expose of SVNClient.
+     * (This used to cause a fatal exception in the Java Runtime)
+     */
+    public void testDispose() throws Throwable
+    {
+      SVNClient cl = new SVNClient();
+      cl.dispose();
+    }
+
+    /**
      * @return <code>file</code> converted into a -- possibly
      * <code>canonical</code>-ized -- Subversion-internal path
      * representation.
@@ -3593,8 +3680,17 @@ public class BasicTests extends SVNTests
                                       Map<String, byte[]> revprops,
                                       boolean hasChildren)
             {
-                String author = new String(revprops.get("svn:author"));
-                String message = new String(revprops.get("svn:log"));
+                String author, message;
+                try {
+                    author = new String(revprops.get("svn:author"), "UTF8");
+                } catch (UnsupportedEncodingException e) {
+                    author = new String(revprops.get("svn:author"));
+                }
+                try {
+                    message = new String(revprops.get("svn:log"), "UTF8");
+                } catch (UnsupportedEncodingException e) {
+                    message = new String(revprops.get("svn:log"));
+                }
                 long timeMicros;
 
                 try {

Modified: subversion/branches/svn_mutex/subversion/bindings/javahl/tests/org/apache/subversion/javahl/SVNTests.java
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/javahl/tests/org/apache/subversion/javahl/SVNTests.java?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/javahl/tests/org/apache/subversion/javahl/WC.java (original)
+++ subversion/branches/svn_mutex/subversion/bindings/javahl/tests/org/apache/subversion/javahl/WC.java Tue Oct 11 19:52:34 2011
@@ -519,6 +519,9 @@ public class WC
                                         + item.myPath + "' don't match:",
                                         item.reposLastCmtAuthor,
                                         status.getReposLastCmtAuthor());
+                    Assert.assertNotNull("URL for path " + item.myPath
+                                         + " should not be null", 
+                                         status.getUrl());
                 }
             }
             item.touched = true;

Modified: subversion/branches/svn_mutex/subversion/bindings/javahl/tests/org/tigris/subversion/javahl/SVNTests.java
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/javahl/tests/org/tigris/subversion/javahl/SVNTests.java?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/swig/core.i (original)
+++ subversion/branches/svn_mutex/subversion/bindings/swig/core.i Tue Oct 11 19:52:34 2011
@@ -244,6 +244,7 @@
 %ignore svn_auth_kwallet_version;
 %ignore svn_auth_get_kwallet_simple_provider;
 %ignore svn_auth_get_kwallet_ssl_client_cert_pw_provider;
+%ignore svn_auth_get_gpg_agent_simple_provider;
 
 /* bad pool convention */
 %ignore svn_opt_print_generic_help;

Modified: subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Base.pm
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Base.pm?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Base.pm (original)
+++ subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Base.pm Tue Oct 11 19:52:34 2011
@@ -55,8 +55,8 @@ sub import {
     my (undef, $pkg, $prefix, @ignore) = @_;
     no warnings 'uninitialized';
     unless (${"SVN::_${pkg}::ISA"}[0] eq 'DynaLoader') {
-	@{"SVN::_${pkg}::ISA"} = qw(DynaLoader);
-	eval qq'
+        @{"SVN::_${pkg}::ISA"} = qw(DynaLoader);
+        eval qq'
 package SVN::_$pkg;
 require DynaLoader;
 bootstrap SVN::_$pkg;
@@ -69,23 +69,23 @@ bootstrap SVN::_$pkg;
     my $prefix_re = qr/(?i:$prefix)/;
     my $ignore_re = join('|', @ignore);
     for (keys %{"SVN::_${pkg}::"}) {
-	my $name = $_;
-	next unless s/^$prefix_re//;
-	next if $ignore_re && m/$ignore_re/;
-
-	# insert the accessor
-	if (m/(.*)_get$/) {
-	    my $member = $1;
-	    *{"${caller}::$1"} = sub {
-		&{"SVN::_${pkg}::${prefix}${member}_".
-		      (@_ > 1 ? 'set' : 'get')} (@_)
-		  }
-	}
-	elsif (m/(.*)_set$/) {
-	}
-	else {
-	    *{"${caller}::$_"} = ${"SVN::_${pkg}::"}{$name};
-	}
+        my $name = $_;
+        next unless s/^$prefix_re//;
+        next if $ignore_re && m/$ignore_re/;
+
+        # insert the accessor
+        if (m/(.*)_get$/) {
+            my $member = $1;
+            *{"${caller}::$1"} = sub {
+                &{"SVN::_${pkg}::${prefix}${member}_".
+                    (@_ > 1 ? 'set' : 'get')}(@_)
+            }
+        }
+        elsif (m/(.*)_set$/) {
+        }
+        else {
+            *{"${caller}::$_"} = ${"SVN::_${pkg}::"}{$name};
+        }
     }
 
 }

Modified: subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Client.pm
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Client.pm?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Client.pm (original)
+++ subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Client.pm Tue Oct 11 19:52:34 2011
@@ -46,8 +46,8 @@ SVN::Client - Subversion client function
               SVN::Client::get_username_provider()]
               );
 
-    $ctx->cat (\*STDOUT, 'http://svn.apache.org/repos/asf/subversion/trunk/README',
-               'HEAD');
+    $ctx->cat(\*STDOUT, 'http://svn.apache.org/repos/asf/subversion/trunk/README',
+              'HEAD');
 
     sub simple_prompt {
       my $cred = shift;
@@ -197,7 +197,7 @@ sub new
     my $self = bless {}, $class;
     my %args = @_;
 
-    $self->{'ctx'} = SVN::_Client::svn_client_create_context ();
+    $self->{'ctx'} = SVN::_Client::svn_client_create_context();
 
     if (defined($args{'auth'}))
     {

Modified: subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Core.pm
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Core.pm?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Core.pm (original)
+++ subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Core.pm Tue Oct 11 19:52:34 2011
@@ -20,10 +20,10 @@ SVN::Core - Core module of the subversio
     sub something {
         # create a subpool of the current default pool
         my $pool = SVN::Pool->new_default_sub;
-	# some svn operations...
+        # some svn operations...
 
-	# $pool gets destroyed and the previous default pool
-	# is restored when $pool's lexical scope ends
+        # $pool gets destroyed and the previous default pool
+        # is restored when $pool's lexical scope ends
     }
 
     # svn_stream_t as native perl io handle
@@ -155,7 +155,7 @@ sub CLOSE
 {
     my $self = shift;
     *$self->{svn_stream}->close
-	if *$self->{svn_stream};
+        if *$self->{svn_stream};
     undef *$self->{svn_stream};
 }
 
@@ -170,7 +170,7 @@ sub GETC
 sub print
 {
     my $self = shift;
-    $self->WRITE ($_[0], length ($_[0]));
+    $self->WRITE($_[0], length($_[0]));
 }
 
 sub PRINT
@@ -178,7 +178,7 @@ sub PRINT
     my $self = shift;
     if (defined $\) {
         if (defined $,) {
-	    $self->print(join($,, @_).$\);
+            $self->print(join($,, @_).$\);
         } else {
             $self->print(join("",@_).$\);
         }
@@ -201,8 +201,8 @@ sub PRINTF
 sub getline
 {
     my $self = shift;
-    *$self->{pool} ||= SVN::Core::pool_create (undef);
-    my ($buf, $eof) = *$self->{svn_stream}->readline ($/, *$self->{pool});
+    *$self->{pool} ||= SVN::Core::pool_create(undef);
+    my ($buf, $eof) = *$self->{svn_stream}->readline($/, *$self->{pool});
     return undef if $eof && !length($buf);
     return $eof ? $buf : $buf.$/;
 }
@@ -220,16 +220,16 @@ sub READLINE
 {
     my $self = shift;
     unless (defined $/) {
-	my $buf = '';
-	while (length( my $chunk = *$self->{svn_stream}->read
-	       ($SVN::Core::STREAM_CHUNK_SIZE)) ) {
-	    $buf .= $chunk;
-	}
-	return $buf;
+        my $buf = '';
+        while (length( my $chunk = *$self->{svn_stream}->read
+               ($SVN::Core::STREAM_CHUNK_SIZE)) ) {
+            $buf .= $chunk;
+        }
+        return $buf;
     }
     elsif (ref $/) {
-        my $buf = *$self->{svn_stream}->read (${$/});
-	return length($buf) ? $buf : undef;
+        my $buf = *$self->{svn_stream}->read(${$/});
+        return length($buf) ? $buf : undef;
     }
     return wantarray ? $self->getlines : $self->getline;
 }
@@ -238,9 +238,9 @@ sub READ {
     my $self = shift;
     my $len = $_[1];
     if (@_ > 2) { # read offset
-        substr($_[0],$_[2]) = *$self->{svn_stream}->read ($len);
+        substr($_[0],$_[2]) = *$self->{svn_stream}->read($len);
     } else {
-        $_[0] = *$self->{svn_stream}->read ($len);
+        $_[0] = *$self->{svn_stream}->read($len);
     }
     return $len;
 }
@@ -263,7 +263,7 @@ sub WRITE {
             my $rem = $slen - $off;
             $len = $rem if $rem < $len;
         }
-	*$self->{svn_stream}->write (substr ($_[0], $off, $len));
+        *$self->{svn_stream}->write(substr($_[0], $off, $len));
     }
     return $len;
 }
@@ -285,7 +285,7 @@ my %WRAPPED;
 
 sub default {
     my ($pool) = @_;
-    my $pobj = SVN::Pool->_wrap ($$pool);
+    my $pobj = SVN::Pool->_wrap($$pool);
     $WRAPPED{$pool} = $pobj;
     $pobj->default;
 }
@@ -315,11 +315,11 @@ also use $pool-E<gt>default to make it t
 
 =over 4
 
-=item new ([$parent])
+=item new([$parent])
 
 Create a new pool. The pool is a root pool if $parent is not supplied.
 
-=item new_default ([$parent])
+=item new_default([$parent])
 
 Create a new pool. The pool is a root pool if $parent is not supplied.
 Set the new pool as default pool.
@@ -355,14 +355,14 @@ my @POOLSTACK;
 
 sub new {
     my ($class, $parent) = @_;
-    $parent = $$parent if ref ($parent) eq 'SVN::Pool';
-    my $self = bless \create ($parent), $class;
+    $parent = $$parent if ref($parent) eq 'SVN::Pool';
+    my $self = bless \create($parent), $class;
     return $self;
 }
 
 sub new_default_sub {
-    my $parent = ref ($_[0]) ? ${+shift} : $SVN::_Core::current_pool;
-    my $self = SVN::Pool->new_default ($parent);
+    my $parent = ref($_[0]) ? ${+shift} : $SVN::_Core::current_pool;
+    my $self = SVN::Pool->new_default($parent);
     return $self;
 }
 
@@ -375,13 +375,13 @@ sub new_default {
 sub default {
     my $self = shift;
     push @POOLSTACK, $SVN::_Core::current_pool
-	unless $$SVN::_Core::current_pool == 0;
+        unless $$SVN::_Core::current_pool == 0;
     $SVN::_Core::current_pool = $$self;
 }
 
 sub clear {
     my $self = shift;
-    apr_pool_clear ($$self);
+    apr_pool_clear($$self);
 }
 
 my $globaldestroy;
@@ -419,7 +419,7 @@ sub DESTROY {
         delete $WRAPPOOL{$self};
     }
     else {
-        apr_pool_destroy ($$self)
+        apr_pool_destroy($$self)
     }
 }
 
@@ -427,28 +427,28 @@ package _p_svn_error_t;
 use SVN::Base qw(Core svn_error_t_);
 
 sub strerror {
-	return SVN::Error::strerror($_[$[]->apr_err());
+    return SVN::Error::strerror($_[$[]->apr_err());
 }
 
 sub handle_error {
-	return SVN::Error::handle_error(@_);
+    return SVN::Error::handle_error(@_);
 }
 
 sub expanded_message {
-	return SVN::Error::expanded_message(@_);
+    return SVN::Error::expanded_message(@_);
 }
 
 sub handle_warning {
-	# need to swap parameter order.
-	return SVN::Error::handle_warning($_[$[+1],$_[$[]);
+    # need to swap parameter order.
+    return SVN::Error::handle_warning($_[$[+1],$_[$[]);
 }
 
 foreach my $function (qw(compose clear quick_wrap)) {
     no strict 'refs';
     my $real_function = \&{"SVN::_Core::svn_error_$function"};
     *{"_p_svn_error_t::$function"} = sub {
-			  return $real_function->(@_);
-		}
+        return $real_function->(@_);
+    }
 }
 
 package SVN::Error;
@@ -457,8 +457,8 @@ use SVN::Base qw(Core SVN_ERR_);
 use Carp;
 our @CARP_NOT = qw(SVN::Base SVN::Client SVN::Core SVN::Delta
                    SVN::Delta::Editor SVN::Error SVN::Fs SVN::Node
-									 SVN::Pool SVN::Ra SVN::Ra::Callbacks SVN::Ra::Reporter
-									 SVN::Repos SVN::Stream SVN::TxDelta SVN::Wc);
+                   SVN::Pool SVN::Ra SVN::Ra::Callbacks SVN::Ra::Reporter
+                   SVN::Repos SVN::Stream SVN::TxDelta SVN::Wc);
 
 =head2 svn_error_t - SVN::Error
 
@@ -560,9 +560,9 @@ our $handler = \&croak_on_error;
 foreach my $function (qw(handle_error handle_warning strerror)) {
     no strict 'refs';
     my $real_function = \&{"SVN::_Core::svn_$function"};
-	  *{"SVN::Error::$function"} = sub {
-	      return $real_function->(@_);
-		}
+    *{"SVN::Error::$function"} = sub {
+        return $real_function->(@_);
+    }
 }
 
 =item SVN::Error::expanded_message($svn_error_t) or $svn_error_t-E<gt>expanded_message()
@@ -574,17 +574,18 @@ exception handlers get their error messa
 =cut
 
 sub expanded_message {
-	  my $svn_error = shift;
+    my $svn_error = shift;
     unless (is_error($svn_error)) {
-	      return undef;
-		}
+        return undef;
+    }
 
-		my $error_message = $svn_error->strerror();
-		while ($svn_error) {
-		    $error_message .= ': ' . $svn_error->message();
-				$svn_error = $svn_error->child();
-		}
-		return $error_message;
+    my $error_message = $svn_error->strerror();
+    while ($svn_error) {
+        my $msg = $svn_error->message();
+        $error_message .= ": $msg" if $msg;
+        $svn_error = $svn_error->child();
+    }
+    return $error_message;
 }
 
 
@@ -597,7 +598,7 @@ an error.
 =cut
 
 sub is_error {
-		 return (ref($_[$[]) eq '_p_svn_error_t');
+     return (ref($_[$[]) eq '_p_svn_error_t');
 }
 
 =item SVN::Error::croak_on_error
@@ -620,16 +621,16 @@ unchanged.
 =cut
 
 sub croak_on_error {
-		unless (is_error($_[$[])) {
-			return @_;
-		}
+    unless (is_error($_[$[])) {
+      return @_;
+    }
     my $svn_error = shift;
 
-		my $error_message = $svn_error->expanded_message();
+    my $error_message = $svn_error->expanded_message();
 
-		$svn_error->clear();
+    $svn_error->clear();
 
-		croak($error_message);
+    croak($error_message);
 }
 
 =item SVN::Error::confess_on_error
@@ -641,16 +642,16 @@ This is useful when you are doing develo
 =cut
 
 sub confess_on_error {
-		unless (is_error($_[$[])) {
-				return @_;
-		}
+    unless (is_error($_[$[])) {
+        return @_;
+    }
     my $svn_error = shift;
 
-		my $error_message = $svn_error->expanded_message();
+    my $error_message = $svn_error->expanded_message();
 
-		$svn_error->clear();
+    $svn_error->clear();
 
-		confess($error_message);
+    confess($error_message);
 }
 
 =item SVN::Error::ignore_error
@@ -665,11 +666,11 @@ clears it.  It then returns all the othe
 
 sub ignore_error {
     if (is_error($_[$[])) {
-		    my $svn_error = shift;
-				$svn_error->clear();
-		}
+        my $svn_error = shift;
+        $svn_error->clear();
+    }
 
-		return @_;
+    return @_;
 }
 
 package _p_svn_log_changed_path_t;

Modified: subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Delta.pm
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Delta.pm?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Delta.pm (original)
+++ subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Delta.pm Tue Oct 11 19:52:34 2011
@@ -17,21 +17,21 @@ SVN::Delta - Subversion delta functions
     # driving an editor
     my $editor = SVN::Delta::Editor->
         new(SVN::Repos::get_commit_editor($repos, "file://$repospath",
-       	                                  '/', 'root', 'FOO', \&committed));
+                                          '/', 'root', 'FOO', \&committed));
 
     my $rootbaton = $editor->open_root(0);
 
-    my $fbaton = $editor->add_file ('filea', $rootbaton,
-	 		            undef, -1);
+    my $fbaton = $editor->add_file('filea', $rootbaton,
+                                   undef, -1);
 
-    my $ret = $editor->apply_textdelta ($fbaton, undef);
+    my $ret = $editor->apply_textdelta($fbaton, undef);
     SVN::TxDelta::send_string("FILEA CONTENT", @$ret);
 
     # implement an editor in perl
     SVN::Repos::dir_delta($root1, $path, undef,
-			  $root2, $path,
-			  SVN::Delta::Editor->new(_debug=>1),
-			  1, 1, 0, 1
+                          $root2, $path,
+                          SVN::Delta::Editor->new(_debug=>1),
+                          1, 1, 0, 1
 
 =head1 DESCRIPTION
 
@@ -56,11 +56,11 @@ use and its method calls will be relayed
 If you want to implement an editor, subclass SVN::Delta::Editor and
 implement the editors callbacks. see the METHODS section below.
 
-=head2 CONSTRUCTOR - new (...)
+=head2 CONSTRUCTOR - new(...)
 
 =over
 
-=item new ($editor, $editor_baton)
+=item new($editor, $editor_baton)
 
 Link to the native editor
 
@@ -106,9 +106,9 @@ use SVN::Base qw(Delta svn_txdelta_ appl
 # in Perl land.
 sub apply {
     if (@_ == 5 || (@_ == 4 && ref($_[-1]) ne 'SVN::Pool' && ref($_[-1]) ne '_p_apr_pool_t')) {
-	splice(@_, 3, 1);
-	my @ret = SVN::_Delta::svn_txdelta_apply(@_);
-	return @ret[1,2];
+        splice(@_, 3, 1);
+        my @ret = SVN::_Delta::svn_txdelta_apply(@_);
+        return @ret[1,2];
     }
     goto \&SVN::_Delta::svn_txdelta_apply;
 }
@@ -127,10 +127,10 @@ use SVN::Base qw(Delta svn_delta_editor_
 sub convert_editor {
     my $self = shift;
     $self->{_editor} = $_[0], return 1
-	if UNIVERSAL::isa ($_[0], __PACKAGE__);
+        if UNIVERSAL::isa($_[0], __PACKAGE__);
     if (ref($_[0]) && $_[0]->isa('_p_svn_delta_editor_t')) {
-	@{$self}{qw/_editor _baton/} = @_;
-	return 1;
+        @{$self}{qw/_editor _baton/} = @_;
+        return 1;
     }
     return 0;
 }
@@ -140,9 +140,9 @@ sub new {
     my $self = bless {}, $class;
 
     unless ($self->convert_editor(@_)) {
-	%$self = @_;
-	$self->convert_editor (@{$self->{_editor}})
-	    if $self->{_editor};
+        %$self = @_;
+        $self->convert_editor(@{$self->{_editor}})
+            if $self->{_editor};
     }
 
     return $self;
@@ -160,18 +160,18 @@ sub AUTOLOAD {
     return unless $func =~ m/[^A-Z]/;
 
     my %ebaton = ( set_target_revision => 1,
-		   open_root => 1,
-		   close_edit => 1,
-		   abort_edit => 1,
-		 );
+                   open_root => 1,
+                   close_edit => 1,
+                   abort_edit => 1,
+                 );
 
     my $self = shift;
     no strict 'refs';
 
-    my @ret = UNIVERSAL::isa ($self->{_editor}, __PACKAGE__) ?
-	$self->{_editor}->$func (@_) :
+    my @ret = UNIVERSAL::isa($self->{_editor}, __PACKAGE__) ?
+        $self->{_editor}->$func(@_) :
         eval { &{"invoke_$func"}($self->{_editor},
-				 $ebaton{$func} ? $self->{_baton} : (), @_) };
+                                 $ebaton{$func} ? $self->{_baton} : (), @_) };
 
     die $@ if $@;
 

Modified: subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Fs.pm
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Fs.pm?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Fs.pm (original)
+++ subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Fs.pm Tue Oct 11 19:52:34 2011
@@ -166,10 +166,10 @@ The oldest revision in any filesystem is
 
 =cut
 
-our @methods = qw/youngest_rev revision_root revision_prop revision_proplist
-		  change_rev_prop list_transactions open_txn begin_txn
-		  get_uuid set_uuid set_access get_access
-                  lock unlock get_lock get_locks generate_lock_token path/;
+our @methods = qw/ youngest_rev revision_root revision_prop revision_proplist
+                   change_rev_prop list_transactions open_txn begin_txn
+                   get_uuid set_uuid set_access get_access
+                   lock unlock get_lock get_locks generate_lock_token path /;
 
 for (@methods) {
     no strict 'refs';
@@ -270,14 +270,14 @@ For transaction roots, returns C<$SVN::C
 
 =cut
 
-our @methods = qw/apply_textdelta apply_text change_node_prop
-		 check_path close_root copied_from copy
-		 dir_entries delete file_contents closest_copy
-		 file_length file_md5_checksum is_dir is_file
-		 is_revision_root is_txn_root make_dir make_file
-		 node_created_rev node_history node_id node_prop
-		 node_proplist paths_changed revision_link
-		 revision_root_revision/;
+our @methods = qw/ apply_textdelta apply_text change_node_prop
+                   check_path close_root copied_from copy
+                   dir_entries delete file_contents closest_copy
+                   file_length file_md5_checksum is_dir is_file
+                   is_revision_root is_txn_root make_dir make_file
+                   node_created_rev node_history node_id node_prop
+                   node_proplist paths_changed revision_link
+                   revision_root_revision /;
 
 *fs = *SVN::Fs::root_fs;
 *txn_name = *_p_svn_fs_txn_t::root_name;

Modified: subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Makefile.PL.in
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Makefile.PL.in?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Makefile.PL.in (original)
+++ subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Makefile.PL.in Tue Oct 11 19:52:34 2011
@@ -47,12 +47,11 @@ my @ldmodules = map {"-lsvn_$_-1"} (@mod
 my $apr_shlib_path_var = '@SVN_APR_SHLIB_PATH_VAR@';
 my $cppflags = '@CPPFLAGS@';
 my $cflags = '@CFLAGS@';
-my $apr_cflags = '@SVN_APR_INCLUDES@';
-my $apu_cflags = '@SVN_APRUTIL_INCLUDES@';
+my $includes = '@SVN_APR_INCLUDES@ @SVN_APRUTIL_INCLUDES@';
 
 # According to the log of r7937, the flags guarded by the conditional break
 # the build on FreeBSD if not conditionalized.
-my $apr_ldflags = '@SVN_APR_LIBS@' 
+my $apr_ldflags = '@SVN_APR_LIBS@'
    if $^O eq 'darwin' or $^O eq 'cygwin';
 
 chomp $apr_shlib_path_var;
@@ -60,8 +59,8 @@ chomp $apr_shlib_path_var;
 my %config = (
     ABSTRACT => 'Perl bindings for Subversion',
     DEFINE => $cppflags,
-    CCFLAGS => $cflags,
-    INC  => join(' ',$apr_cflags, $apu_cflags, 
+    CCFLAGS => join(' ', $cflags, $Config{ccflags}),
+    INC  => join(' ', $includes, $cppflags,
                  " -I$swig_srcdir/perl/libsvn_swig_perl",
                  " -I$svnlib_srcdir/include",
                  " -I$svnlib_builddir",
@@ -104,8 +103,8 @@ for (@modules) {
 # the dependencies need to be fixed
 
 sub MY::postamble {
-    my $module_c_files = join (' ',map { "svn_$_.c"} @modules);
-    my $module_make_commands = join ('',map {"\t\$(MAKE) -f Makefile.$_\n"} @modules);
+    my $module_c_files = join(' ',map { "svn_$_.c"} @modules);
+    my $module_make_commands = join('',map {"\t\$(MAKE) -f Makefile.$_\n"} @modules);
 
     my $fullperlrun = "$apr_shlib_path_var=" .
                       join(':', "\$($apr_shlib_path_var)", @ldpaths);

Modified: subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Ra.pm
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Ra.pm?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Ra.pm (original)
+++ subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Ra.pm Tue Oct 11 19:52:34 2011
@@ -505,7 +505,7 @@ sub new {
             # If the auth is already set to a auth_baton ignore it
             # otherwise make an auth_baton and store the callbacks
             my ($auth_baton, $auth_callbacks) =
-                                SVN::Core::auth_open_helper($self->{auth});
+                SVN::Core::auth_open_helper($self->{auth});
             $self->{auth} = $auth_baton;
             $self->{auth_provider_callbacks} = $auth_callbacks;
         }

Modified: subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Repos.pm
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Repos.pm?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Repos.pm (original)
+++ subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/Repos.pm Tue Oct 11 19:52:34 2011
@@ -71,7 +71,7 @@ Example:
     use SVN::Core;
     use SVN::Repos;
 
-    my $repos = SVN::Repos::open ('/repo/sandbox');
+    my $repos = SVN::Repos::open('/repo/sandbox');
 
     open my $fh, ">/tmp/tmp.dump" or die "Cannot open file: $!\n";
 
@@ -124,7 +124,7 @@ Example:
     use SVN::Core;
     use SVN::Repos;
 
-    my $repos = SVN::Repos::open ('/repo/test_repo');
+    my $repos = SVN::Repos::open('/repo/test_repo');
 
     open my $fh, "/repo/sandbox.dump" or die "Cannot open file: $!\n";
 

Modified: subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/scripts/compile_all.pl
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/scripts/compile_all.pl?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/scripts/compile_all.pl (original)
+++ subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/scripts/compile_all.pl Tue Oct 11 19:52:34 2011
@@ -19,5 +19,5 @@
 use strict;
 
 for my $file qw( Client.pm Core.pm Delta.pm Fs.pm Ra.pm Repos.pm Wc.pm ) {
-	system("$^X -Mblib scripts/fast_svnbase.pl $file > blib/lib/SVN/${file}c");
+    system("$^X -Mblib scripts/fast_svnbase.pl $file > blib/lib/SVN/${file}c");
 }

Modified: subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/scripts/fast_svnbase.pl
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/scripts/fast_svnbase.pl?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/scripts/fast_svnbase.pl (original)
+++ subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/scripts/fast_svnbase.pl Tue Oct 11 19:52:34 2011
@@ -72,21 +72,21 @@ sub _compile_import {
     my @subs;
     no strict 'refs';
     for (keys %{"SVN::_${pkg}::"}) {
-	my $name = $_;
-	next unless s/^$prefix_re//;
-	next if $ignore_re && m/$ignore_re/;
+        my $name = $_;
+        next unless s/^$prefix_re//;
+        next if $ignore_re && m/$ignore_re/;
 
-	# insert the accessor
-	if (m/(.*)_get$/) {
-	    my $member = $1;
-	    push @subs, qq!*$member = sub { &{"SVN::_${pkg}::${prefix}${member}_".
-		      (\@_ > 1 ? 'set' : 'get')}(\@_)} !;
-	}
-	elsif (m/(.*)_set$/) {
-	}
-	else {
-	    push @subs, qq!*$_ = \$SVN::_${pkg}::{$name}!;
-	}
+        # insert the accessor
+        if (m/(.*)_get$/) {
+            my $member = $1;
+            push @subs, qq!*$member = sub { &{"SVN::_${pkg}::${prefix}${member}_".
+                                            (\@_ > 1 ? 'set' : 'get')}(\@_)} !;
+        }
+        elsif (m/(.*)_set$/) {
+        }
+        else {
+            push @subs, qq!*$_ = \$SVN::_${pkg}::{$name}!;
+        }
     }
     return "{ no strict 'refs';\n  ". join(";\n  ", @subs, '')."}\n";
 }

Modified: subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/t/1repos.t
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/t/1repos.t?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/t/1repos.t (original)
+++ subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/t/1repos.t Tue Oct 11 19:52:34 2011
@@ -46,15 +46,15 @@ sub committed {
 
 my $editor = SVN::Delta::Editor->
     new(SVN::Repos::get_commit_editor($repos, "file://$repospath",
-				      '/', 'root', 'FOO', \&committed));
+                                      '/', 'root', 'FOO', \&committed));
 
 my $rootbaton = $editor->open_root(0);
 
-my $dirbaton = $editor->add_directory ('trunk', $rootbaton, undef, 0);
+my $dirbaton = $editor->add_directory('trunk', $rootbaton, undef, 0);
 
-my $fbaton = $editor->add_file ('trunk/filea', $dirbaton, undef, -1);
+my $fbaton = $editor->add_file('trunk/filea', $dirbaton, undef, -1);
 
-my $ret = $editor->apply_textdelta ($fbaton, undef);
+my $ret = $editor->apply_textdelta($fbaton, undef);
 
 SVN::TxDelta::send_string("FILEA CONTENT", @$ret);
 
@@ -63,13 +63,13 @@ $editor->close_edit();
 cmp_ok($fs->youngest_rev, '==', 1);
 {
 $editor = SVN::Delta::Editor->
-    new (SVN::Repos::get_commit_editor($repos, "file://$repospath",
-				       '/', 'root', 'FOO', \&committed));
+    new(SVN::Repos::get_commit_editor($repos, "file://$repospath",
+                                      '/', 'root', 'FOO', \&committed));
 my $rootbaton = $editor->open_root(1);
 
-my $dirbaton = $editor->add_directory ('tags', $rootbaton, undef, 1);
-my $subdirbaton = $editor->add_directory ('tags/foo', $dirbaton, 
-					  "file://$repospath/trunk", 1);
+my $dirbaton = $editor->add_directory('tags', $rootbaton, undef, 1);
+my $subdirbaton = $editor->add_directory('tags/foo', $dirbaton,
+                                         "file://$repospath/trunk", 1);
 
 $editor->close_edit();
 }
@@ -77,27 +77,27 @@ cmp_ok($fs->youngest_rev, '==', 2);
 
 my @history;
 
-SVN::Repos::history ($fs, 'tags/foo/filea',
-		     sub {push @history, [@_[0,1]]}, 0, 2, 1);
+SVN::Repos::history($fs, 'tags/foo/filea',
+                    sub {push @history, [@_[0,1]]}, 0, 2, 1);
 
-is_deeply (\@history, [['/tags/foo/filea',2],['/trunk/filea',1]],
-	   'repos_history');
+is_deeply(\@history, [['/tags/foo/filea',2],['/trunk/filea',1]],
+          'repos_history');
 
 {
 my $pool = SVN::Pool->new_default;
 my $something = bless {}, 'something';
 $editor = SVN::Delta::Editor->
-    new (SVN::Repos::get_commit_editor($repos, "file://$repospath",
-				       '/', 'root', 'FOO', sub {committed(@_);
-                                                                $something;
-                                                            }));
+    new(SVN::Repos::get_commit_editor($repos, "file://$repospath",
+                                      '/', 'root', 'FOO', sub {committed(@_);
+                                                               $something;
+                                                          }));
 
 my $rootbaton = $editor->open_root(2);
 $editor->delete_entry('tags', 2, $rootbaton);
 
 $editor->close_edit();
 }
-ok ($main::something_destroyed, 'callback properly destroyed');
+ok($main::something_destroyed, 'callback properly destroyed');
 
 cmp_ok($fs->youngest_rev, '==', 3);
 

Modified: subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/t/2fs.t
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/t/2fs.t?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/t/2fs.t (original)
+++ subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/t/2fs.t Tue Oct 11 19:52:34 2011
@@ -80,7 +80,7 @@ ok($root->is_file($path), 'is_file');
     my $stream = $root->file_contents($path);
     local $/;
     is(<$stream>, $text, 'content verified');
-    is($root->file_md5_checksum ($path), 'dd2314129f81675e95b940ff94ddc935',
+    is($root->file_md5_checksum($path), 'dd2314129f81675e95b940ff94ddc935',
        'md5 verified');
 }
 

Modified: subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/t/3client.t
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/t/3client.t?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/t/3client.t (original)
+++ subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/t/3client.t Tue Oct 11 19:52:34 2011
@@ -26,7 +26,7 @@ use strict;
 # shut up about variables that are only used once.
 # these come from constants and variables used
 # by the bindings but not elsewhere in perl space.
-no warnings 'once'; 
+no warnings 'once';
 
 use_ok('SVN::Core');
 use_ok('SVN::Repos');
@@ -74,7 +74,7 @@ ok(SVN::Client::uuid_from_url($reposurl,
 ok(SVN::Client::uuid_from_url($reposurl,$ctx->{'ctx'}),
    'Valid return from uuid_from_url function form with _p_svn_client_ctx object');
 
-             
+
 my ($ci_dir1) = $ctx->mkdir(["$reposurl/dir1"]);
 isa_ok($ci_dir1,'_p_svn_client_commit_info_t');
 $current_rev++;
@@ -133,8 +133,8 @@ is($ctx->add("$wcpath/dir1/new",0),undef
    'Returned undef from add schedule operation');
 
 # test the log_msg callback
-$ctx->log_msg( 
-    sub 
+$ctx->log_msg(
+    sub
     {
         my ($log_msg,$tmp_file,$commit_items,$pool) = @_;
         isa_ok($log_msg,'SCALAR','log_msg param to callback is a SCALAR');
@@ -202,11 +202,11 @@ is($ctx->info("$wcpath/dir1/new", undef,
 my $svn_error = $ctx->info("$wcpath/dir1/newxyz", undef, 'WORKING', sub {}, 0);
 isa_ok($svn_error, '_p_svn_error_t',
        'info should return _p_svn_error_t for a nonexistent file');
-$svn_error->clear(); #don't leak this 
+$svn_error->clear(); #don't leak this
 
 # test getting the log
 is($ctx->log("$reposurl/dir1/new",$current_rev,$current_rev,1,0,
-             sub 
+             sub
              {
                  my ($changed_paths,$revision,
                      $author,$date,$message,$pool) = @_;
@@ -239,7 +239,7 @@ is($ctx->update($wcpath,'HEAD',1),$curre
    'Return from update is the current rev');
 
 # no return so we should get undef as the result
-# we will get a _p_svn_error_t if there is an error. 
+# we will get a _p_svn_error_t if there is an error.
 is($ctx->propset('perl-test','test-val',"$wcpath/dir1",0),undef,
    'propset on a working copy path returns undef');
 
@@ -248,7 +248,7 @@ isa_ok($ph,'HASH','propget returns a has
 is($ph->{"$wcpath/dir1"},'test-val','perl-test property has the correct value');
 
 # No revnum for the working copy so we should get INVALID_REVNUM
-is($ctx->status($wcpath, undef, sub { 
+is($ctx->status($wcpath, undef, sub {
                                       my ($path,$wc_status) = @_;
                                       is($path,"$wcpath/dir1",
                                          'path param to status callback is' .
@@ -390,21 +390,21 @@ SKIP: {
     # one command to run to test it.  If you want to use this you need
     # to change the usernames, passwords, and paths to the client cert.
     # It assumes that there is a repo running on localhost port 443 at
-    # via SSL.  The repo cert should trip a client trust issue.  The 
+    # via SSL.  The repo cert should trip a client trust issue.  The
     # client cert should be encrypted and require a pass to use it.
     # Finally uncomment the skip line below.
 
-    # Before shipping make sure the following line is uncommented. 
+    # Before shipping make sure the following line is uncommented.
     skip 'Impossible to test without external effort to setup https', 7;
- 
+
     sub simple_prompt {
         my $cred = shift;
         my $realm = shift;
         my $username_passed = shift;
-        my $may_save = shift; 
+        my $may_save = shift;
         my $pool = shift;
- 
-        ok(1,'simple_prompt called'); 
+
+        ok(1,'simple_prompt called');
         $cred->username('breser');
         $cred->password('foo');
     }
@@ -416,7 +416,7 @@ SKIP: {
         my $cert_info = shift;
         my $may_save = shift;
         my $pool = shift;
-  
+
         ok(1,'ssl_server_trust_prompt called');
         $cred->may_save(0);
         $cred->accepted_failures($failures);
@@ -436,10 +436,10 @@ SKIP: {
         my $cred = shift;
         my $may_save = shift;
         my $pool = shift;
-    
+
         ok(1,'ssl_client_cert_pw_prompt called');
         $cred->password('test');
-    } 
+    }
 
     my $oldauthbaton = $ctx->auth();
 
@@ -453,9 +453,9 @@ SKIP: {
                                 \&ssl_client_cert_pw_prompt,2)
               ),'_p_svn_auth_baton_t',
               'auth() accessor returns _p_svn_auth_baton');
-     
-    # if this doesn't work we will get an svn_error_t so by 
-    # getting a hash we know it worked. 
+
+    # if this doesn't work we will get an svn_error_t so by
+    # getting a hash we know it worked.
     my ($dirents) = $ctx->ls('https://localhost/svn/test','HEAD',1);
     isa_ok($dirents,'HASH','ls returns a HASH');
 

Modified: subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/t/4pool.t
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/t/4pool.t?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/t/4pool.t (original)
+++ subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/t/4pool.t Tue Oct 11 19:52:34 2011
@@ -28,7 +28,7 @@ use File::Temp qw(tempdir);
 # shut up about variables that are only used once.
 # these come from constants and variables used
 # by the bindings but not elsewhere in perl space.
-no warnings 'once'; 
+no warnings 'once';
 
 require SVN::Core;
 require SVN::Repos;
@@ -41,14 +41,14 @@ our @ISA = qw(SVN::Delta::Editor);
 sub add_directory {
     my ($self, $path, undef, undef, undef, $pool) = @_;
     $pool->default;
-    main::is_pool_default ($pool, 'default pool from c calls');
+    main::is_pool_default($pool, 'default pool from c calls');
 }
 
 package main;
 sub is_pool_default {
     my ($pool, $text) = @_;
-    is (ref ($pool) eq 'SVN::Pool' ? $$$pool : $$pool,
-	$$SVN::_Core::current_pool, $text);
+    is(ref($pool) eq 'SVN::Pool' ? $$$pool : $$pool,
+       $$SVN::_Core::current_pool, $text);
 }
 
 my $repospath = tempdir('svn-perl-test-XXXXXX', TMPDIR => 1, CLEANUP => 1);
@@ -62,16 +62,16 @@ my $fs = $repos->fs;
 
 my $pool = SVN::Pool->new_default;
 
-is_pool_default ($pool, 'default pool');
+is_pool_default($pool, 'default pool');
 
 {
     my $spool = SVN::Pool->new_default_sub;
-    is_pool_default ($spool, 'lexical default pool default');
+    is_pool_default($spool, 'lexical default pool default');
 }
 
-is_pool_default ($pool, 'lexical default pool destroyed');
+is_pool_default($pool, 'lexical default pool destroyed');
 
-my $root = $fs->revision_root (0);
+my $root = $fs->revision_root(0);
 
 my $txn = $fs->begin_txn(0);
 
@@ -80,13 +80,13 @@ $txn->root->make_dir('trunk');
 $txn->commit;
 
 
-SVN::Repos::dir_delta ($root, '', '',
-		       $fs->revision_root (1), '',
-		       TestEditor->new(),
-		       undef, 1, 1, 0, 1);
+SVN::Repos::dir_delta($root, '', '',
+                      $fs->revision_root(1), '',
+                      TestEditor->new(),
+                      undef, 1, 1, 0, 1);
 
 
-is_pool_default ($pool, 'default pool from c calls destroyed');
+is_pool_default($pool, 'default pool from c calls destroyed');
 
 END {
 diag('cleanup');

Modified: subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/t/5delta-compat.t
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/t/5delta-compat.t?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/t/5delta-compat.t (original)
+++ subversion/branches/svn_mutex/subversion/bindings/swig/perl/native/t/5delta-compat.t Tue Oct 11 19:52:34 2011
@@ -31,13 +31,13 @@ open my $source, '<', \$srctext;
 open my $target, '<', \$tgttext;
 open my $aresult, '>', \$result;
 
-my $txstream = SVN::TxDelta::new ($source, $target);
+my $txstream = SVN::TxDelta::new($source, $target);
 
-isa_ok ($txstream, '_p_svn_txdelta_stream_t');
+isa_ok($txstream, '_p_svn_txdelta_stream_t');
 open my $asource, '<', \$srctext;
-my $handle = [SVN::TxDelta::apply ($asource, $aresult, undef, undef)];
+my $handle = [SVN::TxDelta::apply($asource, $aresult, undef, undef)];
 
-SVN::TxDelta::send_txstream ($txstream, @$handle);
+SVN::TxDelta::send_txstream($txstream, @$handle);
 
-is ($result, $tgttext, 'delta self test');
+is($result, $tgttext, 'delta self test');
--- subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/callback/CommitMessageCallback.java (original)
+++ subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/callback/CommitMessageCallback.java Tue Oct 11 19:52:34 2011
@@ -29,7 +29,7 @@ import org.apache.subversion.javahl.Comm
 
 /**
  * This is callback interface which has to implemented by the client
  * to receive which files will be commited and to enter the log
  * message.
  */
 public interface CommitMessageCallback
@@ -37,8 +37,8 @@ public interface CommitMessageCallback
     /**
      * Retrieve a commit message from the user based on the items to
      * be committed
      * @param elementsToBeCommited Array of elements to be commited
      * @return the log message of the commit.
      */
-    String getLogMessage(Set<CommitItem> elementsToBeCommited);
+    String getLogMessage(Set<CommitItem> elementsToBeCommitted);
 }
@@ -29,7 +29,7 @@ import org.apache.subversion.javahl.Comm
 /**
  * This is callback interface which has to implemented by the client
- * to receive which files will be commited and to enter the log
+ * to receive which files will be committed and to enter the log
  * message.
  */
@@ -37,8 +37,8 @@ public interface CommitMessageCallback
      * Retrieve a commit message from the user based on the items to
      * be committed
-     * @param elementsToBeCommited Array of elements to be commited
+     * @param elementsToBeCommitted Array of elements to be committed
      * @return the log message of the commit.
      */

Modified: subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/types/ChangePath.java
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/apache/subversion/javahl/types/ChangePath.java?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/CommitMessage.java (original)
+++ subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/CommitMessage.java Tue Oct 11 19:52:34 2011
@@ -25,7 +25,7 @@ package org.tigris.subversion.javahl;
 
 /**
  * This is callback interface which has to implemented by the client
  * to receive which files will be commited and to enter the log
  * message.
  */
 public interface CommitMessage
@@ -33,8 +33,8 @@ public interface CommitMessage
     /**
      * Retrieve a commit message from the user based on the items to
      * be committed
      * @param elementsToBeCommited Array of elements to be commited
      * @return the log message of the commit.
      */
-    String getLogMessage(CommitItem[] elementsToBeCommited);
+    String getLogMessage(CommitItem[] elementsToBeCommitted);
 }
@@ -25,7 +25,7 @@ package org.tigris.subversion.javahl;
 /**
  * This is callback interface which has to implemented by the client
- * to receive which files will be commited and to enter the log
+ * to receive which files will be committed and to enter the log
  * message.
  */
@@ -33,8 +33,8 @@ public interface CommitMessage
      * Retrieve a commit message from the user based on the items to
      * be committed
-     * @param elementsToBeCommited Array of elements to be commited
+     * @param elementsToBeCommitted Array of elements to be committed
      * @return the log message of the commit.
      */

Modified: subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/Revision.java
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/javahl/src/org/tigris/subversion/javahl/Revision.java?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/javahl/tests/org/apache/subversion/javahl/SVNTests.java (original)
+++ subversion/branches/svn_mutex/subversion/bindings/javahl/tests/org/apache/subversion/javahl/SVNTests.java Tue Oct 11 19:52:34 2011
@@ -794,14 +794,14 @@ class SVNTests extends TestCase
     {
         /**
          * Retrieve a commit message from the user based on the items
          * to be commited
          * @param elementsToBeCommited  Array of elements to be commited
          * @return  the log message of the commit.
          */
-        public String getLogMessage(Set<CommitItem> elementsToBeCommited)
+        public String getLogMessage(Set<CommitItem> elementsToBeCommitted)
         {
             // check all received CommitItems are expected as received
-            for (CommitItem commitItem : elementsToBeCommited)
+            for (CommitItem commitItem : elementsToBeCommitted)
             {
                 // since imports do not provide a url, the key is either url or
                 // path
@@ -840,7 +840,7 @@ class SVNTests extends TestCase
          */
         NodeKind myNodeKind;
         /**
          * the reason why this item is commited (see CommitItemStateFlag)
          */
         int myStateFlags;
         /**
@@ -794,14 +794,14 @@ class SVNTests extends TestCase
         /**
          * Retrieve a commit message from the user based on the items
-         * to be commited
-         * @param elementsToBeCommited  Array of elements to be commited
+         * to be committed
+         * @param elementsToBeCommitted  Array of elements to be committed
          * @return  the log message of the commit.
          */
@@ -840,7 +840,7 @@ class SVNTests extends TestCase
         NodeKind myNodeKind;
         /**
-         * the reason why this item is commited (see CommitItemStateFlag)
+         * the reason why this item is committed (see CommitItemStateFlag)
          */
         int myStateFlags;

Modified: subversion/branches/svn_mutex/subversion/bindings/javahl/tests/org/apache/subversion/javahl/WC.java
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/javahl/tests/org/apache/subversion/javahl/WC.java?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================
--- subversion/branches/svn_mutex/subversion/bindings/javahl/tests/org/tigris/subversion/javahl/SVNTests.java (original)
+++ subversion/branches/svn_mutex/subversion/bindings/javahl/tests/org/tigris/subversion/javahl/SVNTests.java Tue Oct 11 19:52:34 2011
@@ -868,16 +868,16 @@ class SVNTests extends TestCase
     {
         /**
          * Retrieve a commit message from the user based on the items
          * to be commited
          * @param elementsToBeCommited  Array of elements to be commited
          * @return  the log message of the commit.
          */
-        public String getLogMessage(CommitItem[] elementsToBeCommited)
+        public String getLogMessage(CommitItem[] elementsToBeCommitted)
         {
             // check all received CommitItems are expected as received
-            for (int i = 0; i < elementsToBeCommited.length; i++)
+            for (int i = 0; i < elementsToBeCommitted.length; i++)
             {
-                CommitItem commitItem = elementsToBeCommited[i];
+                CommitItem commitItem = elementsToBeCommitted[i];
                 // since imports do not provide a url, the key is either url or
                 // path
                 String key;
@@ -918,7 +918,7 @@ class SVNTests extends TestCase
          */
         int myNodeKind;
         /**
          * the reason why this item is commited (see CommitItemStateFlag)
          */
         int myStateFlags;
         /**
@@ -868,16 +868,16 @@ class SVNTests extends TestCase
         /**
          * Retrieve a commit message from the user based on the items
-         * to be commited
-         * @param elementsToBeCommited  Array of elements to be commited
+         * to be committed
+         * @param elementsToBeCommitted  Array of elements to be committed
          * @return  the log message of the commit.
          */
@@ -918,7 +918,7 @@ class SVNTests extends TestCase
         int myNodeKind;
         /**
-         * the reason why this item is commited (see CommitItemStateFlag)
+         * the reason why this item is committed (see CommitItemStateFlag)
          */
         int myStateFlags;

Modified: subversion/branches/svn_mutex/subversion/bindings/swig/core.i
URL: http://svn.apache.org/viewvc/subversion/branches/svn_mutex/subversion/bindings/swig/core.i?rev=1182053&r1=1182052&r2=1182053&view=diff
==============================================================================